data1 = "ノーマル"
data2 = "ほのお"
data3 = "みず"
data4 = "でんき"
data5 = "くさ"
data6 = "こおり"
data7 = "かくとう"
data8 = "どく"
data9 = "じめん"
data10 = "ひこう"
data11 = "エスパー"
data12 = "むし"
data13 = "いわ"
data14 = "ゴースト"
data15 = "ドラゴン"
data16 = "あく"
data17 = "はがね"
data18 = "フェアリー"
